##################
Participation Flow
##################

This section describes the data donation flow from a participant's perspective.
This should help researchers to optimize their data donation projects.

.. todo::
    Add Content.
